  
# 学生管理系统

## 目录结构
20student_manager/
├── student_manager/  # 包目录，内含 model.py、manager.py、main.py、etc.
    ├── config.py
    ├── database.py
    ├── repository.py
    ├── logger.py
    ├── main.py
├── setup.py
└── README.md
